@@ -25,13 +25,13 @@ def save_to_dynamo(table_name, item: dict, *args, **kwargs):
     if not response.get('Item') or kwargs.get('overwrite_existing'):
 
         if response.get('Item'):
-            print('overwrite existing dynamo id:', item['id'])
+            print('overwrite existing dynamo table: %s id: %s' % (table_name, item['id']))
 
         response = table.put_item(Item=dict_to_dynamo(item))
 
         print('Saved to dynamo table: %s id: %s' % (table_name, item['id']))
     else:
-        print('Skipping, this item already exists in dynamo id:', item['id'])
+        print('Skipping, this item already exists in dynamo table: %s id: %s' % (table_name, item['id']))
 
     return response
 
@@ -63,11 +63,18 @@ def add_dynamo_metadata(data):
 
 
 def get_dynamo_items(table_name, table_filter=None, *args, **kwargs):
+    if not table_filter:
+        table_filter = {}
     RETRY_EXCEPTIONS = ('ProvisionedThroughputExceededException',
                         'ThrottlingException')
     table = dynamodb.Table(table_name)
 
-    response = table.scan(**table_filter)
+    get_table_items = table.scan
+    if kwargs.get('table_get_type') == 'query':
+        get_table_items = table.query
+        print('get_dynamo_items() get_table_items, table_filter', get_table_items, table_filter)
+
+    response = get_table_items(**table_filter)
     items = response['Items']
 
     # todo watch for memory overflow in batching all the items as once
@@ -78,14 +85,18 @@ def get_dynamo_items(table_name, table_filter=None, *args, **kwargs):
     while 'LastEvaluatedKey' in response and retries < max_retry:
         try:
 
-            response = table.scan(ExclusiveStartKey=response['LastEvaluatedKey'], **table_filter)
+            print('items retrieved:', len(items))
+
+            # if len(items) > 1000:
+            #     return dynamo_to_dict(items)
+            response = get_table_items(ExclusiveStartKey=response['LastEvaluatedKey'], **table_filter)
             items.extend(response['Items'])
             retries = 0
         except ClientError as err:
             if err.response['Error']['Code'] not in RETRY_EXCEPTIONS:
                 raise
             print('WHOA, too fast, slow it down retries={}, items={}'.format(retries, len(items)), )
-            sleep(2 ** retries)
+            sleep(1.3 ** retries)
             retries += 1  # TODO max limit
 
     return dynamo_to_dict(items)
